summaryrefslogtreecommitdiff
path: root/pystache
diff options
context:
space:
mode:
authorChris Jerdonek <chris.jerdonek@gmail.com>2012-03-31 09:53:29 -0700
committerChris Jerdonek <chris.jerdonek@gmail.com>2012-03-31 09:53:29 -0700
commit1542217e351fd9c45d25178e0fc92a91a5449cee (patch)
tree900c80ce71eb1d481a2a00125f82acfec88be16e /pystache
parentce5cc9748c8929a045d3993790bd01ee51fc7020 (diff)
downloadpystache-1542217e351fd9c45d25178e0fc92a91a5449cee.tar.gz
Renamed CustomizedTemplate to TemplateSpec.
Diffstat (limited to 'pystache')
-rw-r--r--pystache/init.py4
-rw-r--r--pystache/template_spec.py9
2 files changed, 6 insertions, 7 deletions
diff --git a/pystache/init.py b/pystache/init.py
index ab59440..5ca096a 100644
--- a/pystache/init.py
+++ b/pystache/init.py
@@ -6,11 +6,11 @@ This module contains the initialization logic called by __init__.py.
"""
from .template_spec import View
-from .template_spec import CustomizedTemplate
+from .template_spec import TemplateSpec
from .renderer import Renderer
-__all__ = ['render', 'Renderer', 'View', 'CustomizedTemplate']
+__all__ = ['render', 'Renderer', 'View', 'TemplateSpec']
def render(template, context=None, **kwargs):
diff --git a/pystache/template_spec.py b/pystache/template_spec.py
index 5f6a79b..1fd54a9 100644
--- a/pystache/template_spec.py
+++ b/pystache/template_spec.py
@@ -13,8 +13,7 @@ from .locator import Locator
from .renderer import Renderer
-# TODO: consider renaming this to something like Template or TemplateInfo.
-class CustomizedTemplate(object):
+class TemplateSpec(object):
"""
A mixin for specifying custom template information.
@@ -52,7 +51,7 @@ class CustomizedTemplate(object):
# TODO: remove this class.
-class View(CustomizedTemplate):
+class View(TemplateSpec):
_renderer = None
@@ -185,13 +184,13 @@ class CustomLoader(object):
def load(self, custom):
"""
Find and return the template associated to a CustomizedTemplate instance.
Returns the template as a unicode string.
Arguments:
- custom: a CustomizedTemplate instance.
+ custom: a TemplateSpec instance.
"""
if custom.template is not None:
@@ -185,13 +184,13 @@ class CustomLoader(object):
def load(self, custom):
"""
- Find and return the template associated to a CustomizedTemplate instance.
+ Find and return the template associated to a TemplateSpec instance.
Returns the template as a unicode string.
Arguments: